==> asksuite-core-1.0.126.tgz: package/infochat.service.js <==
var request = require('request');



module.exports  = function(config){

    var requester = {};

    requester.list = function () {

        var promise = new Promise(function (resolve, reject) {

            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/chattrees",
                json: true,
            }, function (err, httpResponse, body) {

                if (!err) {

                    console.log("######################");
                    //console.log(body);
                    resolve(body);
                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });


        return promise;
    }


    requester.listCompanies = function () {

        var promise = new Promise(function (resolve, reject) {


            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/companies",
                json: true,
            }, function (err, httpResponse, body) {

                if (!err) {
                    resolve(body);
                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });


        return promise;
    }


    requester.findCompany = function (id) {

        var promise = new Promise(function (resolve, reject) {

            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/companies/"+id,
                json: true,
            }, function (err, httpResponse, body) {

                if (!err) {
                    resolve(body);
                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });


        return promise;
    }


    requester.findTree = function (id) {

        var promise = new Promise(function (resolve, reject) {

            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/chattrees/"+id,
                json: true,
            }, function (err, httpResponse, body) {

                if (!err) {

                    try{
                        resolve(body);
                    }catch (e){
                        console.log(e);
                        reject(e);
                    }


                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });


        return promise;
    }


    requester.findTreeByCompanyId = function (numero, text) {

        var promise = new Promise(function (resolve, reject) {

            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/chattrees/"+treeId+"/findByCompanyId",
                json: true,
            }, function (err, httpResponse, body) {

                if (!err) {
                    resolve(body);
                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });


        return promise;
    }


    requester.listKeywordsExpressions = function () {

        return new Promise(function (resolve, reject) {
            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/keywordintents",
                json: true,
            }, function (err, httpResponse, body) {

                if (!err) {

                    try {
                        resolve(body);
                    } catch (e) {
                        console.log(e);
                        reject(e);
                    }

                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });

    }



        return requester;


};

==> asksuite-core-1.0.139.tgz: package/infochat.service.js <==
var request = require('request');



module.exports  = function(config){

    var requester = {};

    requester.list = function () {

        var promise = new Promise(function (resolve, reject) {

            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/chattrees",
                json: true,
                headers: {
                    'Authorization': config.USER_TOKEN
                }
            }, function (err, httpResponse, body) {

                if (!err) {

                    console.log("######################");
                    //console.log(body);
                    resolve(body);
                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });

        return promise;
    }


    requester.listCompanies = function () {

        var promise = new Promise(function (resolve, reject) {


            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/companies",
                json: true,
                headers: {
                    'Authorization': config.USER_TOKEN
                }
            }, function (err, httpResponse, body) {

                if (!err) {
                    resolve(body);
                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });


        return promise;
    }


    requester.findCompany = function (id) {

        var promise = new Promise(function (resolve, reject) {

            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/companies/"+id,
                json: true,
            }, function (err, httpResponse, body) {

                if (!err) {
                    resolve(body);
                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });


        return promise;
    }


    requester.findTree = function (id) {

        var promise = new Promise(function (resolve, reject) {

            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/chattrees/"+id,
                json: true,
                headers: {
                    'Authorization': config.USER_TOKEN
                }
            }, function (err, httpResponse, body) {

                if (!err) {

                    try{
                        resolve(body);
                    }catch (e){
                        console.log(e);
                        reject(e);
                    }


                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });


        return promise;
    }


    requester.findTreeByCompanyId = function (treeId) {

        var promise = new Promise(function (resolve, reject) {

            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/chattrees/"+treeId+"/findByCompanyId",
                json: true,
                headers: {
                    'Authorization': config.USER_TOKEN
                }
            }, function (err, httpResponse, body) {

                if (!err) {
                    resolve(body);
                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });


        return promise;
    }


    requester.listKeywordsExpressions = function () {

        return new Promise(function (resolve, reject) {
            request.get({
                url: config.INFOCHAT_DATA_SERVER + "/keywordintents",
                json: true,
            }, function (err, httpResponse, body) {

                if (!err) {

                    try {
                        resolve(body);
                    } catch (e) {
                        console.log(e);
                        reject(e);
                    }

                } else {
                    console.log("erro ao listar dados", err);
                    reject(err);
                }

            })

        });

    }

        return requester;

};
